@@ -44,6 +44,14 @@ class TestClient(unittest.TestCase):
         'maxmind': {
             'queries_remaining': 11
         },
+        'registered_country': {
+            'geoname_id': 2,
+            'is_in_european_union': True,
+            'iso_code': 'DE',
+            'names': {
+                'en': 'Germany'
+            }
+        },
         'traits': {
             'ip_address': '1.2.3.4'
         },
@@ -59,7 +67,9 @@ class TestClient(unittest.TestCase):
             self.base_uri + 'country/1.2.3.4',
             json=self.country,
             status_code=200,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         country = self.client.country('1.2.3.4')
         self.assertEqual(
             type(country), geoip2.models.Country,
@@ -71,6 +81,8 @@ class TestClient(unittest.TestCase):
                          'continent name is North America')
         self.assertEqual(country.country.geoname_id, 1,
                          'country geoname_id is 1')
+        self.assertIs(country.country.is_in_european_union, False,
+                      'country is_in_european_union is False')
         self.assertEqual(country.country.iso_code, 'US',
                          'country iso_code is US')
         self.assertEqual(country.country.names,
@@ -79,6 +91,8 @@ class TestClient(unittest.TestCase):
                          'country name is United States of America')
         self.assertEqual(country.maxmind.queries_remaining, 11,
                          'queries_remaining is 11')
+        self.assertIs(country.registered_country.is_in_european_union, True,
+                      'registered_country is_in_european_union is True')
         self.assertEqual(country.raw, self.country, 'raw response is correct')
 
     @requests_mock.mock()
@@ -87,7 +101,9 @@ class TestClient(unittest.TestCase):
             self.base_uri + 'country/me',
             json=self.country,
             status_code=200,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         implicit_me = self.client.country()
         self.assertEqual(
             type(implicit_me), geoip2.models.Country,
@@ -102,7 +118,9 @@ class TestClient(unittest.TestCase):
         mock.get(
             self.base_uri + 'country/1.1.1.1',
             status_code=200,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         with self.assertRaisesRegex(GeoIP2Error,
                                     'could not decode the response as JSON'):
             self.client.country('1.1.1.1')
@@ -119,7 +137,9 @@ class TestClient(unittest.TestCase):
             self.base_uri + 'country/' + '1.2.3.7',
             text='',
             status_code=400,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         with self.assertRaisesRegex(
                 HTTPError, 'Received a 400 error for .* with no body'):
             self.client.country('1.2.3.7')
@@ -130,7 +150,9 @@ class TestClient(unittest.TestCase):
             self.base_uri + 'country/' + '1.2.3.8',
             text='{"wierd": 42}',
             status_code=400,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         with self.assertRaisesRegex(HTTPError,
                                     'Response contains JSON but it does not '
                                     'specify code or error keys'):
@@ -142,7 +164,9 @@ class TestClient(unittest.TestCase):
             self.base_uri + 'country/' + '1.2.3.9',
             text='bad body',
             status_code=400,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         with self.assertRaisesRegex(
                 HTTPError, 'it did not include the expected JSON body'):
             self.client.country('1.2.3.9')
@@ -159,7 +183,9 @@ class TestClient(unittest.TestCase):
         mock.get(
             self.base_uri + 'country/' + '1.2.3.11',
             status_code=300,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         with self.assertRaisesRegex(HTTPError,
                                     'Received a very surprising HTTP status '
                                     '\(300\) for'):
@@ -214,7 +240,9 @@ class TestClient(unittest.TestCase):
             self.base_uri + 'country/1.2.3.18',
             json=body,
             status_code=status,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         with self.assertRaisesRegex(error_class, msg):
             self.client.country('1.2.3.18')
 
@@ -227,7 +255,9 @@ class TestClient(unittest.TestCase):
             self.base_uri + 'country/' + ip,
             json=body,
             status_code=400,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         with self.assertRaisesRegex(InvalidRequestError, msg):
             self.client.country(ip)
 
@@ -237,7 +267,9 @@ class TestClient(unittest.TestCase):
             self.base_uri + 'country/' + '1.2.3.4',
             json=self.country,
             status_code=200,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         self.client.country('1.2.3.4')
         request = mock.request_history[-1]
 
@@ -256,7 +288,9 @@ class TestClient(unittest.TestCase):
             self.base_uri + 'city/' + '1.2.3.4',
             json=self.country,
             status_code=200,
-            headers={'Content-Type': self._content_type('city')})
+            headers={
+                'Content-Type': self._content_type('city')
+            })
         city = self.client.city('1.2.3.4')
         self.assertEqual(
             type(city), geoip2.models.City, 'return value of client.city')
@@ -267,7 +301,9 @@ class TestClient(unittest.TestCase):
             self.base_uri + 'insights/1.2.3.4',
             json=self.country,
             status_code=200,
-            headers={'Content-Type': self._content_type('country')})
+            headers={
+                'Content-Type': self._content_type('country')
+            })
         insights = self.client.insights('1.2.3.4')
         self.assertEqual(
             type(insights), geoip2.models.Insights,
